==> pyz-charts-vue3-0.0.1.tgz: package/README.md <==

>  Vue.js 3.x

## Pyz-Charts-vue3
- pyz-charts-vue will stay with Vue 3.x
- [[pyz-charts vue2.x](https://www.npmjs.com/package/pyz-charts)]pyz-charts vue2.x

## Install
[![Build Status](https://github.com/tj/commander.js/workflows/build/badge.svg)](https://github.com/tj/commander.js/actions?query=workflow%3A%22build%22)
[![NPM Version](http://img.shields.io/npm/v/pyz-charts.svg?style=flat)](https://www.npmjs.org/package/pyz-charts-vue3)
[![NPM Downloads](https://img.shields.io/npm/dm/pyz-charts-vue3.svg?style=flat)](https://npmcharts.com/compare/pyz-charts-vue3?minimal=true)
[![Install Size](https://packagephobia.now.sh/badge?p=pyz-charts)](https://packagephobia.now.sh/result?p=pyz-charts-vue3)

```js
// main.js 
import Vue from 'vue';
import PyzCharts from "pyz-charts-vue3";

const app = createApp(App)
app.use(PyzCharts)
```
## Quick Start
``` vue
<!-- a.template -->
<template>
  <pyz-charts @init="callbackEchartsInstance" :option="youEhartsOption"/>
</template>
```
-1. Encapsulates all ecarts events and supports all events @ click, etc

-2. The @ init event callback (instance) instance can be used for deep detection and extension.

-3. Option binding v-bind is the option configuration file of ecarts, which can be written as an instance of the option class

![image](https://m.qpic.cn/psc?/V51ZBodV00BBWb0BqWnT2LcHfN1UCFpB/bqQfVz5yrrGYSXMvKr.cqbcCjXse69.kgcZur164k.VDi3TXqMGsfkJmOe6ZUrznKQQEinFzvfZmzBvbDCzt3Le7GqH.xiSoQb*zn1NtTtY!/b&bo=Ygc4BAAAAAABB3k!&rf=viewer_4)

-For example:
``` vue
<!-- a.template -->
<template>
  <pyz-charts @click="clickMethod" 
  @mousemove="mousemoveMethod" 
  @mouseover="mouseoverMethod" 
  @keydown="keydownMethod" 
  @keyup="keyupMethod" 
  ...
  :option="youEhartsOption"/>
</template>

``` vue
<!-- a.template -->
<template>
  <pyz-charts
  mapJSON
  :json-map="jsonMap"
  map-name="map"
  ...
  :option="youEhartsOption"/>
</template>
```

#### Option建议写法
``` typescript
  'use strict'
  class CarOption {
      public option: EchartsTypeOption;
      constructor(props){
         this.option = {};
      }
  }
```

``` vue
<script>
// a.vue
  export default {
      ...
     methods: {
         callbackEchartsInstance(ecInstance) {
            ?ecInstance.setOption(option)
            or
            ?ecInstance?....
         }
     }
  }
</script>
```


## Browser Support
- 支持Vue
- ES6 module



## Development
- Vue Cli、vite2 + Vue3

## 作者
- 彭一真
## LICENSE
[MIT](LICENSE)

==> pyz-charts-vue3-0.0.5.tgz: package/README.md <==

>  Vue.js 3.x

## Pyz-Charts-vue3
- pyz-charts-vue will stay with Vue 3.x
- [[pyz-charts vue2.x](https://www.npmjs.com/package/pyz-charts)]pyz-charts vue2.x

## Install
[![Build Status](https://github.com/tj/commander.js/workflows/build/badge.svg)](https://github.com/tj/commander.js/actions?query=workflow%3A%22build%22)
[![NPM Version](http://img.shields.io/npm/v/pyz-charts-vue3.svg?style=flat)](https://www.npmjs.org/package/pyz-charts-vue3)
[![NPM Downloads](https://img.shields.io/npm/dm/pyz-charts-vue3.svg?style=flat)](https://npmcharts.com/compare/pyz-charts-vue3?minimal=true)
[![Install Size](https://packagephobia.now.sh/badge?p=pyz-charts-vue3)](https://packagephobia.now.sh/result?p=pyz-charts-vue3)

```js
// main.js 
import Vue from 'vue';
import PyzCharts from "pyz-charts-vue3";

const app = createApp(App)
app.use(PyzCharts)
```
## Quick Start
``` vue
<!-- a.template -->
<template>
  <pyz-charts @init="callbackEchartsInstance" :option="youEhartsOption"/>
</template>
```
-1. Encapsulates all ecarts events and supports all events @ click, etc

-2. The @ init event callback (instance) instance can be used for deep detection and extension.

-3. Option binding v-bind is the option configuration file of ecarts, which can be written as an instance of the option class

![image](https://m.qpic.cn/psc?/V51ZBodV00BBWb0BqWnT2LcHfN1UCFpB/bqQfVz5yrrGYSXMvKr.cqbcCjXse69.kgcZur164k.VDi3TXqMGsfkJmOe6ZUrznKQQEinFzvfZmzBvbDCzt3Le7GqH.xiSoQb*zn1NtTtY!/b&bo=Ygc4BAAAAAABB3k!&rf=viewer_4)

-For example:
``` vue
<!-- a.template -->
<template>
  <pyz-charts @click="clickMethod" 
  @mousemove="mousemoveMethod" 
  @mouseover="mouseoverMethod" 
  @keydown="keydownMethod" 
  @keyup="keyupMethod" 
  ...
  :option="youEhartsOption"/>
</template>

``` vue
<!-- a.template -->
<template>
  <pyz-charts
  mapJSON
  :json-map="jsonMap"
  map-name="map"
  ...
  :option="youEhartsOption"/>
</template>
```

#### Option建议写法
``` typescript
  'use strict'
  class CarOption {
      public option: EchartsTypeOption;
      constructor(props){
         this.option = {};
      }
  }
```

``` vue
<script>
// a.vue
  export default {
      ...
     methods: {
         callbackEchartsInstance(ecInstance) {
            ?ecInstance.setOption(option)
            or
            ?ecInstance?....
         }
     }
  }
</script>
```


## Browser Support
- 支持Vue
- ES6 module



## Development
- Vue Cli、vite2 + Vue3

## 作者
- 彭一真
## LICENSE
[MIT](LICENSE)
